# !/usr/bin/env python
# -*- coding:utf-8 -*-
'''
Adapter
'''


# 适配器模式
# 将一个类的接口转换成客户希望的另外一个接口。使得原本由于接口不兼容而不能一起工作的那些类可以一起工作。
# 应用场景：希望复用一些现存的类，但是接口又与复用环境要求不一致。

def printInfo(info):
    print(info)


# 球员类
class Player():
    name = ''

    def __init__(self, name):
        self.name = name

    def Attack(self, name):
        pass

    def Defense(self):
        pass


# 前锋
class Forwards(Player):
    def __init__(self, name):
        Player.__init__(self, name)

    def Attack(self):
        printInfo("前锋%s 进攻" % self.name)

    def Defense(self):
        printInfo("前锋%s 防守" % self.name)


# 中锋（目标类）
class Center(Player):
    def __init__(self, name):
        Player.__init__(self, name)

    def Attack(self):
        printInfo("中锋%s 进攻" % self.name)

    def Defense(self):
        printInfo("中锋%s 防守" % self.name)


# 后卫
class Guards(Player):
    def __init__(self, name):
        Player.__init__(self, name)

    def Attack(self):
        printInfo("后卫%s 进攻" % self.name)

    def Defense(self):
        printInfo("后卫%s 防守" % self.name)


# 外籍中锋（待适配类）
# 中锋
class ForeignCenter(Player):
    name = ''

    def __init__(self, name):
        Player.__init__(self, name)

    def ForeignAttack(self):
        printInfo("外籍中锋%s 进攻" % self.name)

    def ForeignDefense(self):
        printInfo("外籍中锋%s 防守" % self.name)


# 翻译（适配类）
class Translator(Player):
    foreignCenter = None

    def __init__(self, name):
        self.foreignCenter = ForeignCenter(name)

    def Attack(self):
        self.foreignCenter.ForeignAttack()

    def Defense(self):
        self.foreignCenter.ForeignDefense()


def clientUI():
    b = Forwards('巴蒂尔')
    ym = Guards('姚明')
    m = Translator('麦克格雷迪')

    b.Attack()
    m.Defense()
    ym.Attack()
    b.Defense()
    return


if __name__ == '__main__':
    clientUI()


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/3/2 
# @Author :wsli
# @File : py_new_init.py
# @Software: PyCharm
"""
python中__new__和__init__的区别?
1.__new__是在实例创建之前被调用的，用于创建实例，然后返回该实例对象，是个静态方法。
2.__init__是当实例对象创建完成后被调用的，用于初始化一个类实例，是个实例方法
注意事项：

1.如果__new__没有返回cls(即当前类)的实例，那么当前类的__init__方法是不会被调用的；
"""
class A():
    def __new__(cls, *args, **kwargs):
        print('this is A __new__')
        # return super(A, cls).__new__(cls)  # 或者下面这种形式，两种都可
        return object.__new__(cls)

    def __init__(self, title):
        print('this is A __init__')
        self.title = title


a = A('python book')
"""
__new__和__init__使用场景
"""


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/3/2 
# @Author :wsli
# @File : py_super_2.py
# @Software: PyCharm
"""
继承父类方法
"""
class Tree:
    def __init__(self, name, age):
        self.name = name
        self.age = age

    def grow(self):
        print("{} tree is growing...now it's {} years old".format(self.name, self.age))

    def seed(self):
        print("{} tree is seeding...".format(self.name))


class Apple(Tree):
    """docstring for ClassName"""

    def __init__(self, name, age, color):
        super().__init__(name, age)
        self.color = color

    def price(self):
        print("One {} tree is 100 dollars".format(self.name))


class Pear(Tree):
    """docstring for ClassName"""

    def __init__(self, name, age, color):
        super().__init__(name, age)
        self.color = color

    def price(self):
        print("One {} {} tree is 80 dollars".format(self.color, self.name))

    def grow(self):
        # 重写父类的方法grow生长
        print("it was {} years old,now it is {} years old".format(self.age, int(self.age) + 1))
class orange(Tree):
    def grow(self):
		#调用父类Tree的方法grow
		super().grow()
		#直接调用Tree类的方法
		Tree('Apple','16').grow()
		#重写父类方法grow
		print("{} tree has changed...".format(self.name))

if __name__ == '__main__':
    a = Apple('White Apple', 8, 'white')
    a.grow()
    a.seed()
    a.price()
    b = Pear('Pear', 8, 'red')
    b.price()
    b.grow()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/3/8 
# @Author :wsli
# @File : py_time.py
# @Software: PyCharm
import time
class Bruce_time:
    def now_default_time(self):
        """
        当前年月日时分秒
        :return:
        """
        return time.strftime('%Y-%m-%d %H:%M:%S')

    def time_add_poor(self):
        """
        时间差
        :return:
        """
        pass


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/2/6 
# @Author :wsli
# @File : siemens_plc.py
# @Software: PyCharm
import snap7
import struct
from decimal import Decimal
"""
西门子plc
'PE': 0x81, #input,I
'PA': 0x82, #output,Q
'MK': 0x83, #bit memory,M
'DB': 0x84, #DB,DBX
'CT': 0x1C, #counters
'TM': 0x1D, #Timers
"""
class Bruce_siemens_plc_client():
    def __init__(self, ip: str, rack: int = 0, slot: int = 1):
        """
        连接初始化
        :param ip:
        :param rack: 通常为0
        :param slot:根据plc安装，一般为0或1
        """
        try:
            self.Client = snap7.client.Client()
            self.Client.connect(ip, rack, slot)
        except Exception as e:
            #b' TCP : Connection refused' 未连接
            #CLI: function refused by CPU 未授权
            print("e", e)

    def get_connected(self)->bool:
        """
        plc连接状态
        :return:
        """
        return self.Client.get_connected()

    def close(self):
        """
        连接关闭
        :return:
        """
        status=self.Client.disconnect()
        return status

    def read_area(self, dbnumber:int, start: int, size: int,area="DB"):
        """
        从PLC读取数据区
        有了它，您可以读取DB，输入，输出，默克，定时器和计数器
        :param dbnumber:需要读取的db编号,数据块
        :param start:开始索引
        :param size:读取字节数
        :param area:读取区域
        :return:
        """
        if area=="DB":
            area_type = snap7.types.Areas.DB
        elif area=="PE":
            area_type = snap7.types.Areas.PE
        elif area == "PA":
            area_type = snap7.types.Areas.PA
        elif area=="MK":
            area_type = snap7.types.Areas.MK
        elif area == "CT":
            area_type = snap7.types.Areas.CT
        elif area == "TM":
            area_type = snap7.types.Areas.TM
        else:
            area_type=None
        buffer=self.Client.read_area(area_type, dbnumber, start, size)
        return buffer

    def read_data_get_real(self,data:bytearray,byte_index:int=0,save_float:int=1):
        """
        获取real的值
        :param data:
        :param byte_index:
        :param save_float:保留小数点后几位
        :return:
        """
        try:
            data=snap7.util.get_real(data,byte_index)
            temp="0."
            if save_float==0:
                temp="0"
            else:
                for i in range(0,save_float):
                    temp=temp+"0"
            float_data_2=Decimal(data).quantize(Decimal(temp))
            return float_data_2
        except Exception as e:
            print(e)

    def py_data_int(self,data:bytearray)->int:
        """
        转为整数型
        :param data:
        :return:
        """
        selfInt = int.from_bytes(data, byteorder='big')
        return selfInt

    def py_data_real(self,data):
        selfReal=struct.unpack('>f',data)
        return selfReal



"""

在Python中，is，==和isinstance是三个不同的概念，具有不同的用途和功能。
1.is 是一个身份运算符，用于比较两个对象的身份是否相同。换句话说，它检查两个引用是否指向内存中的同一位置。例如：
```python
a = [1, 2, 3]
b = a  # b now references the same object as a
print(b is a)  # This will output True
```

2.== 是一个相等运算符，用于比较两个对象的值是否相等。它比较两个对象的值，而不是它们的身份。例如
```python
a = [1, 2, 3]
b = [1, 2, 3]  # b is a new object, even though it has the same elements as a
print(b == a)  # This will output True
```
3.isinstance() 是一个内置函数，用于检查对象是否是特定类的实例。它接受两个参数：要检查的对象和一个类（或一个包含多个类的元组）。它返回一个布尔值，表示对象是否是给定类的实例。例如
```python
class MyClass:
    pass

a = MyClass()
print(isinstance(a, MyClass))  # This will output True
```


--------------------------------------


"""


# def add(*aaa):
#     print(*aaa)#(1,2,3,4,5)
#     print(type(aaa)) #tuple
#     return sum(aaa) # 输出：15
#
# print(add(1, 2, 3, 4, 5))  # 输出：15

import time


# def timer_decorator(func):
#     def wrapper(*args, **kwargs):
#         start_time = time.time()
#         result = func(*args, **kwargs)
#         end_time = time.time()
#         print(f"函数 {func.__name__} 执行时间：{end_time - start_time:.4f} 秒")
#         return result
#     return wrapper
#
# x='1'
# @timer_decorator(x)
# def my_function():
#     # 执行需要计时的代码
#     time.sleep(2)
#     print("函数执行完成！")
#
# my_function()















def test_test(func):
    def warapper():
        start_time=time.time()
        func()
        end_time=time.time()
        print("耗时多久",end_time-start_time)
    return warapper

@test_test
def test_de():
    time.sleep(2)
    print("执行完成")

test_de()


def greet(name):
    print(f"Hello, {name}!")


def greet(age):
    print(f"You are {age} years old.")


greet("Alice")  # 输出 "Hello, Alice!"
greet(25)  # 输出 "You are 25 years old."


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/2/13 
# @Author :wsli
# @File : client.py
# @Software: PyCharm
import threading
import time

import redis
import json
class Bruce_redis():
    def __init__(self,pool):
        self.POOL=pool
        self.redis_client=redis.Redis(connection_pool=pool)
    def get(self, key):
        """
        获取单个值
        :param key:
        :return:
        """
        value = self.redis_client.get(key)
        return value

    def mget(self, *args):
        """
        获取多个值
        :param args:
        :return:
        """
        value = self.redis_client.mget(*args)
        return value

    def set(self, key, value):
        """
        设置单个值
        :param key:
        :param value:
        :return:
        """
        value = self.redis_client.set(key, value)
        return value

    def mset(self, *args, **kwargs):
        """
        设置多个键值
        :return:
        """
        value = self.redis_client.mset(*args, **kwargs)
        return value

    def is_key_true(self, key):
        """
        判断key值是否存在
        :return:
        """
        status = self.redis_client.exists(key)
        return status

    def del_key(self, key):
        """
        删除key
        :param key:
        :return:
        """
        status = self.redis_client.delete(key)
        return status

    def clear_db_data(self):
        """
        清除当前数据库中所有数据
        :return:
        """
        pass

    def clear_dball_data(self):
        """
        清除所有库中所有数据
        :return:
        """
        pass

    def set_json(self, keyName, jsonstr):
        """
        存入json到redis中
        :return:
        """
        jsonstr = json.dumps(jsonstr)
        status=self.redis_client.set(keyName, jsonstr)
        return status

    def get_json(self, keyName):
        """
        获取key的json值
        :param keyName:
        :return:
        """

        val = self.get(keyName)
        return json.loads(val)





class Bruce_redis_pool:
    def __init__(self,host='localhost', port=6379, db=0, pool_size=10,password="",decode_responses=True):
        #创建连接池
        self.host = host
        self.port = port
        self.db = db
        self.pool_size = pool_size
        self.password=password
        self.decode_responses = decode_responses
        self.pool = self._create_pool()


    def _create_pool(self):
        return redis.BlockingConnectionPool(host=self.host, port=self.port, password=self.password, db=self.db, decode_responses=self.decode_responses,
                             max_connections=self.pool_size)



    def create_redis_client(self):
        """
        连接池中拿一个连接，自动回收连接
        """
        # 获取Redis连接
        conn = Bruce_redis(self.pool)
        return conn


class Redis_mock_error:
    def __init__(self):
        pass
    def mock_client_max(self,host='localhost', port=6379, db=0, max_connections=10000,password=""):
        """
        错误示范
        模拟redis客户端连接数超过10000
        cc=Redis_mock_error()
        cc.mock_client_max()
        """
        connections = []
        try:
            for _ in range(max_connections):
                print(f"Creating connection {len(connections) + 1}/{max_connections}")
                connection = redis.Redis(host=host, port=port, db=db,password=password)
                connection.set('key', 'value')  # Do some work with the connection
                connections.append(connection)
        except redis.exceptions.ConnectionError as eroor:
            print("redis连接数已经达到最大值,不能连接了",eroor)
        except Exception as e:
            print("e",e)




"""
redis-py官网https://redis.readthedocs.io/en/latest/examples.html
redis-py库提供了两种连接池：BlockingConnectionPool和ConnectionPool。它们的主要区别在于当连接池中没有可用连接时的行为不同。
BlockingConnectionPool会阻塞并等待直到有可用连接为止，而ConnectionPool则会立即引发ConnectionError异常。
因此，如果你的应用程序需要在没有可用连接时等待并重试，则应该使用BlockingConnectionPool。如果你的应用程序需要立即知道连接池中是否有可用连接，则应该使用ConnectionPool。
另外，BlockingConnectionPool还可以设置一个timeout参数，以避免无限期地等待可用连接。如果在指定的时间内没有可用连接，则会引发ConnectionError异常。
总之，如果你需要在没有可用连接时等待并重试，则使用BlockingConnectionPool；如果你需要立即知道连接池中是否有可用连接，则使用ConnectionPool
"""










#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/2/13 
# @Author :wsli
# @File : py_win.py
# @Software: PyCharm
import win32con
import win32api
import winreg
import os

class Bruce_win():

    def get_registry(self,
                     key_name,
                     reg_root=win32con.HKEY_CURRENT_USER,
                     reg_path = r"SOFTWARE\Microsoft\Windows\CurrentVersion\Run"):
        """
        获取开机启动项
        :param key_name:
        :param reg_root:
        :param reg_path:
        :return:
        """
        reg_flags = win32con.WRITE_OWNER | win32con.KEY_WOW64_64KEY | win32con.KEY_ALL_ACCESS
        try:
            key = winreg.OpenKey(reg_root, reg_path, 0, reg_flags)
            location, type = winreg.QueryValueEx(key, key_name)
            print("键存在", "location（数据）:", location, "type:", type)
            feedback = 0
        except FileNotFoundError as e:
            print("键不存在", e)
            feedback = 1
        except PermissionError as e:
            print("权限不足", e)
            feedback = 2
        except Exception as e:
            print("Error",e)
            feedback = 3
        return feedback

    def autoRun(self,switch="open",  # 开：open # 关：close
                zdynames=None,
                current_file=None,
                abspath=os.path.abspath(os.path.dirname(__file__))):
        """
        :param switch: 注册表开启、关闭自启动
        :param zdynames: 当前文件名 test.py
        :param current_file: 获得文件名的前部分test
        :param abspath: 当前文件路径  D:\
        :return:
        """
        #print(zdynames)

        path = abspath + '\\' + zdynames  # 要添加的exe完整路径如：
        judge_key = self.get_registry(reg_root=win32con.HKEY_CURRENT_USER,
                              reg_path=r"Software\Microsoft\Windows\CurrentVersion\Run",  # 键的路径
                              key_name=current_file)
        # 注册表项名
        KeyName = r'Software\Microsoft\Windows\CurrentVersion\Run'
        key = win32api.RegOpenKey(win32con.HKEY_CURRENT_USER, KeyName, 0, win32con.KEY_ALL_ACCESS)
        if switch == "open":
            # 异常处理
            try:
                if judge_key == 0:
                    print("已经开启了，无需再开启")
                elif judge_key == 1:
                    win32api.RegSetValueEx(key, current_file, 0, win32con.REG_SZ, path)
                    win32api.RegCloseKey(key)
                    print('开机自启动添加成功！')
            except:
                print('添加失败')
        elif switch == "close":
            try:
                if judge_key == 0:
                    win32api.RegDeleteValue(key, current_file)  # 删除值
                    win32api.RegCloseKey(key)
                    print('成功删除键！')
                elif judge_key == 1:
                    print("键不存在")
                elif judge_key == 2:
                    print("权限不足")
                else:
                    print("出现错误")
            except:
                print('删除失败')







import socket
import struct



class Bruce_socket_util():
    def is_port_ok(self):
        """
        查看端口是否有人占用
        """
        pass

    def is_ip_ok(self):
        """
        查看ip是否能ping通
        """
        pass

class Bruce_socket_client(Bruce_socket_util):
    def __init__(self, ip: str = "127.0.0.1", port: int = 8089):
        self.ip = ip
        self.port = port
        self.init_client()
        self._client=None
    def init_client(self):
        """
        初始化客户端
        """
        self._client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.on_content()
    def on_content(self):
        """
        客户端连接服务端
        """
        ip_port = (self.ip, self.port)
        res = self._client.connect_ex(ip_port)

    def send_msg(self,msg:str):
        """
        客户端发送消息
        """
        self._client.send(msg.encode('utf-8'))
    def wait_msg(self):
        """
        客户端等待服务端返回的消息
        """
        message = self._client.recv(1024).decode('utf-8')
        return message

    def close(self):
        """
        关闭客户端
        """
        self._client.close()










class Bruce_socket_server(Bruce_socket_util):
    def __init__(self, ip: str = "127.0.0.1", port: int = 8089,max_content:int=5):
        self.ip = ip
        self.port = port
        self.max_content=max_content
        self.init_server()
        self._server=None
    def init_server(self):
        """
        初始化服务端
        """
        ip_port = (self.ip, self.port)
        self._server= socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self._server.bind(ip_port)
        self._server.listen( self.max_content)# 最大连接数默认为5


    def close(self):
        """
        关闭服务端
        """
        pass





"""
解决粘包的方法：
问题的根源在于，接收端不知道发送端将要传送的字节流的长度，所以解决粘包的方法就是围绕如何让发送端在发送数据前，把自己将要发送的字节流总大小让接收端知晓，然后接收端用一个死循环接收完所有数据；
"""


class Bruce_socket_error_server():

    """
    发生粘包的两种情况
    """
    def __init__(self,ip:str="127.0.0.1",port:int=8089):
        self.ip=ip
        self.port = port

    def error_one_socket_server(self):
        """
        1.发送端需要等缓冲区满才发送出去，造成粘包（发送数据时间间隔很短，数据了很小，会合到一起，产生粘包
        """
        ip_port = (self.ip, self.port)
        tcp_socket_server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        tcp_socket_server.bind(ip_port)
        tcp_socket_server.listen(5)
        conn, addr = tcp_socket_server.accept()
        data1 = conn.recv(10)
        data2 = conn.recv(10)
        print('----->', data1.decode('utf-8'))
        print('----->', data2.decode('utf-8'))
        conn.close()

    def error_two_socket_server(self):
        """
        2.接收方不及时接收缓冲区的包，造成多个包接收（客户端发送了一段数据，服务端只收了一小部分，服务端下次再收的时候还是从缓冲区拿上次遗留的数据，产生粘包）
        """
        self.error_one_socket_server()


class Bruce_socket_error_client():
    """
    发生粘包的两种情况
    """
    def __init__(self,ip:str="127.0.0.1",port:int=8089):
        self.ip=ip
        self.port=port

    def error_one_socket_client(self):
        """
        1.发送端需要等缓冲区满才发送出去，造成粘包（发送数据时间间隔很短，数据了很小，会合到一起，产生粘包
        """
        BUFSIZE = 1024
        ip_port = (self.ip, self.port)
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        res = s.connect_ex(ip_port)
        s.send('hello'.encode('utf-8'))
        s.send('feng'.encode('utf-8'))


    def error_two_socket_client(self):
        """
        2.接收方不及时接收缓冲区的包，造成多个包接收（客户端发送了一段数据，服务端只收了一小部分，服务端下次再收的时候还是从缓冲区拿上次遗留的数据，产生粘包）
        """
        BUFSIZE = 1024
        ip_port = (self.ip, self.port)
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        res = s.connect_ex(ip_port)
        s.send('hello1111111111111111111111111'.encode('utf-8'))
        s.send('feng'.encode('utf-8'))
        self.error_one_socket_client()





#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/3/2 
# @Author :wsli
# @File : py_super.py
# @Software: PyCharm
# coding=utf-8
"""
继承关系
"""
class A(object):
    def __init__(self):
        print("class ---- A ----")
        print("a")


class B(A):
    def __init__(self):
        print("class ---- B ----")
        super(B, self).__init__()
        print("Blia")


class C(A):
    def __init__(self):
        print("class ---- C ----")
        super(C, self).__init__()
        print("CliA")


class D(B, C):
    def __init__(self):
        print("class ---- D ----")
        super(D, self).__init__()
        print("Dl")


d = D()
print(D.__mro__)
'''
#输出结果：
class ---- D ----
class ---- B ----
class ---- C ----
class ---- A ----
'''





import SparkApi





text = []


# length = 0

def getText(role, content):
    jsoncon = {}
    jsoncon["role"] = role
    jsoncon["content"] = content
    text.append(jsoncon)
    return text


def getlength(text):
    length = 0
    for content in text:
        temp = content["content"]
        leng = len(temp)
        length += leng
    return length


def checklen(text):
    while (getlength(text) > 8000):
        del text[0]
    return text

class Py_gpt_config:
    def __init__(self,appid,api_secret,api_key,gpt_version="2"):
        self.Spark_url=None#云端环境的服务地址
        self.domain=""#用于配置大模型版本
        self.appid=appid
        self.api_secret=api_secret
        self.api_key=api_key
        if gpt_version=='2':
            self.version_2_0()
        else:
            self.version_1_5()

    def version_1_5(self):
        self.Spark_url = "ws://spark-api.xf-yun.com/v1.1/chat"
        self.domain="general"

    def version_2_0(self):
        self.Spark_url = "ws://spark-api.xf-yun.com/v2.1/chat"
        self.domain = "generalv2"

def xfxun_gpt(rq_text:str,appid,api_secret,api_key):
    global text
    text.clear()
    Input =rq_text
    question = checklen(getText("user", Input))
    SparkApi.answer = ""
    py_config=Py_gpt_config(appid,api_secret,api_key)
    SparkApi.main(py_config.appid, py_config.api_key, py_config.api_secret, py_config.Spark_url, py_config.domain, question)
    getText("assistant", SparkApi.answer)





from .py_plc import Bruce_siemens_plc_client
from .py_modbus import Bruce_modbus_tcp
from .py_mysql import Bruce_mysql
from .py_redis import Bruce_redis
from .py_request import Bruce_requests
from .py_win32 import Bruce_win
from .py_threading import Bruce_threading
from .py_time import Bruce_time


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/2/13 
# @Author :wsli
# @File : client.py
# @Software: PyCharm
import requests
class Bruce_requests():
    def get(self,url ,params=None, **kwargs):
        try:
            req=requests.get(url, params=params, **kwargs)
            return req.text
        except Exception as e:
            print(e)

    def post(self,url, data=None, json=None, **kwargs):
        try:
            req=requests.post(url, data=data, json=json, **kwargs)
            return req.text
        except Exception as e:
            print(e)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/2/6 
# @Author :wsli
# @File : client.py
# @Software: PyCharm


from modbus_tk import modbus_rtu
import modbus_tk.defines as cst
import serial
from pyModbusTCP.client import ModbusClient

class Bruce_modbus_serial_com():
    def __init__(self,port:str="com1",
                 baudrate:int=9600,
                 bytesize:int=8,
                 parity:str="N",
                 stopbits:int=1):
        """

        :param port:com口
        :param baudrate:波特率
        :param bytesize:几位数据 默认为8
        :param parity:  奇偶校验
        :param stopbits: 停止位
        """
        self.master = modbus_rtu.RtuMaster(serial.Serial(port=port,
                                                    baudrate=baudrate,
                                                    bytesize=bytesize,
                                                    parity=parity,
                                                    stopbits=stopbits))
        self.master.set_timeout(5.0)
        self.master.set_verbose(True)

    def read_h03(self,slave:int, starting_address:int,quantity_of_x:int):
        """
        读线圈
        :param slave:站号
        :param starting_address:地址
        quantity_of_x:长度
        :return:
        """
        data=self.master.execute(slave, cst.READ_HOLDING_REGISTERS, starting_address, quantity_of_x)
        return data


class Bruce_modbus_tcp(ModbusClient):
    def __init__(self,host:str="localhost",port:int=502):
        ModbusClient.__init__(self,host,port)

    def read_holding_registers3(self,address:int,reg_len:int):
        """
        address register address (0 to 65535)
        功能码3 读取单个保持寄存器
        长度 reg_len
        :return:
        """
        regs_ist1 = self.read_holding_registers(reg_addr=address, reg_nb=reg_len)
        return regs_ist1

    def write_single_register6(self, address: int, reg_val: int):
        """
        功能码6 写单个寄存器
        address register address (0 to 65535)
        长度 reg_len
        :return:
        """
        try:
            self.write_single_register(reg_addr=address, reg_value=reg_val)
            return True
        except Exception as e:
            return False
    def write_multiple_registers16(self,address:int,reg_list_val:list):
        """
        功能码16 写多个寄存器的值(顺序的才可以写多个)
        :return:
        """
        try:
            self.write_multiple_registers(regs_addr=address,regs_value=reg_list_val)
            return True
        except Exception as e:
            return False

